# pysndlib

This package provides a python wrapper around sndlib, by Bill Schottstaedt (bil@ccrma.stanford.edu)
Sources for sndlib can be found [here](https://ccrma.stanford.edu/software/snd/sndlib/)

cython is used to generate bindings

This also requires numpy.

For  building instructions and some notes for use look
[here](https://testcase.github.io/pysndlib/readme.html)

Documentation for a number of generators and functions can be found in main [docs](https://testcase.github.io/pysndlib/index.html)
	    


